@@ -3,3 +3,9 @@
 from rastervision.pipeline.runner.inprocess_runner import *
 from rastervision.pipeline.runner.local_runner import *
 from rastervision.pipeline.runner.runner import *
+
+__all__ = [
+    Runner.__name__,
+    LocalRunner.__name__,
+    InProcessRunner.__name__,
+]
