@@ -9,5 +9,5 @@ class Verbosity:
     @staticmethod
     def get() -> 'Verbosity':
         """Get the verbosity from RVConfig."""
-        from rastervision.pipeline import rv_config
+        from rastervision.pipeline import rv_config_ as rv_config
         return rv_config.get_verbosity()
